# SUS02-BP01: Scale workload infrastructure dynamically

## Description

Use auto-scaling để match resources với demand.

## Implementation Guidance

- Configure auto-scaling policies
- Scale to zero when possible
- Use serverless for variable workloads
- Monitor scaling efficiency
- Optimize for minimal over-provisioning

## Risk Level

Medium - Over-provisioning wastes energy.

## Related Best Practices

- [SUS02-BP03](SUS02-BP03-Stop-Unused-Resources.md)
- [REL07-BP01](../../03-REL/REL07-Change-Demand-Handling/REL07-BP01-Use-Automation-To-Manage-Changes.md)
